@@ -7,13 +7,7 @@ HEADERS = {'Content-Type': 'application/json'}
 
 GENERIC_PAYLOAD = {
     "head": {
-        "appName": "",
-        "appVer": "1.0",
         "key": "",
-        "osName": "WEB",
-        "requestCode": "",
-        "userId": "",
-        "password": ""
     },
     "body": {
         "ClientCode": ""
@@ -72,6 +66,8 @@ JWT_PAYLOAD={
     "JWTToken":""
     }
 
+
+
 TODAY_TIMESTAMP = int(datetime.datetime.today().timestamp())
 NEXT_DAY_TIMESTAMP = int(
     (datetime.datetime.today()+datetime.timedelta(days=1)).timestamp())
